@@ -36,10 +36,22 @@ class IndexNodeAdapter(FolderXMLAdapter):
     self.context.clear()
 
   def _initObjects(self, node):
-    return rebindFunction(
-      super(IndexNodeAdapter, self)._initObjects,
-      Products=_O(meta_types=self.context.all_meta_types()),
-      )(self, node)
+    # newer "GenericSetup" versions import "Products" locally
+    #  In order to customize the "meta_types", we use the following hack.
+    #  We temporarily modify "sys.modules" with our products emulation and
+    #  rebind to local name "Products" to the temporary object added
+    #  to "sys.modules".
+    products_emulation = _O(meta_types=self.context.all_meta_types())
+    emu_name = 'managable_index_' + str(id(products_emulation))
+    from sys import modules
+    modules[emu_name] = products_emulation
+    try:
+      return rebindFunction(
+        super(IndexNodeAdapter, self)._initObjects,
+        nameRebindDir=dict(Products=emu_name),
+        Products=products_emulation,
+        )(self, node)
+    finally: del modules[emu_name]
 
   node = property(_exportNode, _importNode)
 
